@@ -4,29 +4,6 @@
 
 .. [1] XCP Specification, BUILD_CHECKSUM service.
 """
-
-__copyright__ = """
-    pySART - Simplified AUTOSAR-Toolkit for Python.
-
-   (C) 2009-2019 by Christoph Schueler <cpu12.gems@googlemail.com>
-
-   All Rights Reserved
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-"""
-
 import enum
 import struct
 import zlib
@@ -694,12 +671,12 @@ def wordSum(modulus, step):
     return add
 
 
-ADD11 = adder(2 ** 8)
-ADD12 = adder(2 ** 16)
-ADD14 = adder(2 ** 32)
-ADD22 = wordSum(2 ** 16, 2)
-ADD24 = wordSum(2 ** 32, 2)
-ADD44 = wordSum(2 ** 32, 4)
+ADD11 = adder(2**8)
+ADD12 = adder(2**16)
+ADD14 = adder(2**32)
+ADD22 = wordSum(2**16, 2)
+ADD24 = wordSum(2**32, 2)
+ADD44 = wordSum(2**32, 4)
 CRC16 = Crc16(CRC16, 0x0000, 0x0000, True, True)
 CRC16_CCITT = Crc16(CRC16_CCITT, 0xFFFF, 0x0000, False, False)
 
