@@ -2,38 +2,15 @@
 # -*- coding: utf-8 -*-
 """
 """
-
-__copyright__ = """
-    pySART - Simplified AUTOSAR-Toolkit for Python.
-
-   (C) 2009-2021 by Christoph Schueler <cpu12.gems@googlemail.com>
-
-   All Rights Reserved
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-"""
-
 import abc
-from bisect import bisect_left
-from collections import OrderedDict
 import functools
 import operator
-from time import perf_counter, time
-
-from pyxcp.transport.base import BaseTransport
+from bisect import bisect_left
+from collections import OrderedDict
 from pyxcp.config import Configuration
+from pyxcp.transport.base import BaseTransport
+from time import perf_counter
+from time import time
 
 
 CAN_EXTENDED_ID = 0x80000000
@@ -366,7 +343,7 @@ class Can(BaseTransport):
         if self.max_dlc_required:
             frame = padFrame(frame, self.padding_value, self.padding_len)
         # send the request
-        if self.perf_counter_origin > 0:
+        if self.perf_counter_origin < 0:
             self.pre_send_timestamp = time()
             self.canInterface.transmit(payload=frame)
             self.post_send_timestamp = time()
